pub struct Framebuffer { /* private fields */ }Expand description
RGBA8 pixel buffer with depth buffer for basic overlap testing.
Implementations
Sourceimpl Framebuffer
impl Framebuffer
Sourcepub fn new(width: u32, height: u32) -> Self
pub fn new(width: u32, height: u32) -> Self
Creates a new framebuffer filled with transparent black.
Sourcepub fn with_color(width: u32, height: u32, color: [f32; 4]) -> Self
pub fn with_color(width: u32, height: u32, color: [f32; 4]) -> Self
Creates a new framebuffer filled with a solid color.
pub fn width(&self) -> u32
pub fn height(&self) -> u32
Sourcepub fn pixels_mut(&mut self) -> &mut [u32]
pub fn pixels_mut(&mut self) -> &mut [u32]
Returns a mutable reference to the raw RGBA8 pixel data.
Sourcepub fn clear_color(&mut self, color: [f32; 4])
pub fn clear_color(&mut self, color: [f32; 4])
Clears the framebuffer to a solid color.